@@ -7,34 +7,34 @@ from miutil import fdio
 
 def test_create_dir(tmp_path, caplog):
     tmpdir = tmp_path / "create_dir"
-    assert not path.exists(fdio.fspath(tmpdir))
+    assert not tmpdir.exists()
     fdio.create_dir(tmpdir)
-    tmpdir = fdio.fspath(tmpdir)
-    assert path.exists(tmpdir)
-    rmtree(tmpdir, True)
+    assert tmpdir.exists() and tmpdir.is_dir()
+    rmtree(fdio.fspath(tmpdir), True)
 
-    with open(tmpdir, "w") as fd:
+    with open(fdio.fspath(tmpdir), "w") as fd:
         fd.write("dummy file")
     with caplog.at_level(logging.INFO):
         assert "cannot create" not in caplog.text
         fdio.create_dir(tmpdir)
         assert "cannot create" in caplog.text
 
-    assert path.exists(tmpdir)
+    assert tmpdir.exists()
 
 
 def test_hasext():
     for fname, ext in [
+        (".baz", ".baz"),
         ("foo.bar", ".bar"),
         ("foo.bar", "bar"),
-        ("foo.bar.baz", "baz"),
+        ("foo.bar.baz", "bar.baz"),
         ("foo/bar.baz", "baz"),
+        ("foo.bar.baz", "baz"),
     ]:
         assert fdio.hasext(fname, ext)
 
     for fname, ext in [
         ("foo.bar", "baz"),
-        ("foo.bar.baz", "bar.baz"),
         ("foo", "foo"),
     ]:
         assert not fdio.hasext(fname, ext)
